@@ -14,10 +14,7 @@ from .core import (
     check_hash_line,
     generate_hash_line,
 )
-from .utils.colorama import cprint, wrap_stream
-from .utils.glob import glob_scanner
-
-_TQDM_ASCII = sys.platform == "win32"
+from .utils.glob import glob_filter
 
 
 class FilePath(click.Path):
@@ -101,6 +98,7 @@ class GetHash(object):
         self.ctx = ctx
 
         self.glob_mode = kwargs.pop("glob", 1)
+        self.glob_type = kwargs.pop("type", "a")
         self.suffix = kwargs.pop("suffix", ".sha")
 
         # Determine the path format.
@@ -114,8 +112,8 @@ class GetHash(object):
         self.output = Output(sep, agg, null)
         self.dump = self.output.dump
 
-        self.stdout = wrap_stream(kwargs.pop("stdout", sys.stdout))
-        self.stderr = wrap_stream(kwargs.pop("stderr", sys.stderr))
+        self.stdout = kwargs.pop("stdout", sys.stdout)
+        self.stderr = kwargs.pop("stderr", sys.stderr)
 
         # Prepare arguments and construct the hash function.
         start = kwargs.pop("start", None)
@@ -133,11 +131,11 @@ class GetHash(object):
         )
 
     def echo(self, msg, **kwargs):
-        cprint(msg, file=self.stdout, **kwargs)
+        click.secho(msg, file=self.stdout, **kwargs)
 
     def echo_error(self, path, exc):
         msg = f"[ERROR] {path}\n\t{type(exc).__name__}: {exc}"
-        cprint(msg, file=self.stderr, fg="red")
+        click.secho(msg, file=self.stderr, fg="red")
 
     def check_root(self, path):
         if self.inplace:
@@ -147,7 +145,7 @@ class GetHash(object):
         return None
 
     def generate_hash(self, patterns):
-        for path in glob_scanner(patterns, mode=self.glob_mode):
+        for path in glob_filter(patterns, mode=self.glob_mode, type=self.glob_type):
             try:
                 root = self.check_root(path)
                 hash_line = generate_hash_line(path, self.hash_function, root=root)
@@ -157,7 +155,7 @@ class GetHash(object):
                 self.echo_error(path, e)
             else:
                 # The hash line already has a newline.
-                self.echo(hash_line, end="")
+                self.echo(hash_line, nl=False)
 
     def _check_hash(self, hash_path):
         for hash_line in HashFileReader(hash_path):
@@ -172,7 +170,9 @@ class GetHash(object):
                 self.echo(f"[SUCCESS] {path}", fg="green")
 
     def check_hash(self, patterns):
-        for hash_path in glob_scanner(patterns, mode=self.glob_mode):
+        for hash_path in glob_filter(
+            patterns, mode=self.glob_mode, type=self.glob_type
+        ):
             try:
                 self._check_hash(hash_path)
             except Exception as e:
@@ -208,7 +208,7 @@ def script_main(ctx, files, **options):
         gh(check, files)
 
 
-def gethashcli(name, suffix):
+def gethashcli(cmdname, hashname, suffix):
     """Generate click decorators for the main function."""
 
     def decorator(func):
@@ -219,13 +219,17 @@ def gethashcli(name, suffix):
             "Output Mode", help="Ignored when -c is set."
         )
 
-        @click.command(no_args_is_help=True)
+        @click.command(
+            cmdname,
+            context_settings=dict(help_option_names=["-h", "--help"]),
+            no_args_is_help=True,
+        )
         @click.argument("files", nargs=-1)
         @click.option(
             "-c",
             "--check",
             is_flag=True,
-            help=f"Read {name} from FILES and check them.",
+            help=f"Read {hashname} from FILES and check them.",
         )
         @click.option("--start", type=click.INT, help="The start offset of files.")
         @click.option("--stop", type=click.INT, help="The stop offset of files.")
@@ -246,6 +250,15 @@ def gethashcli(name, suffix):
             help="Set glob mode. If ``0``, disable glob pathname pattern; if ``1``, "
             "resolve ``*`` and ``?``; if ``2``, resolve ``*``, ``?`` and ``[]``.",
         )
+        @click.option(
+            "-t",
+            "--type",
+            type=click.Choice(["a", "d", "f"]),
+            default="a",
+            show_default=True,
+            help="Set file type. If ``a``, include all types; if ``d``, include "
+            "directories; if ``f``, include files.",
+        )
         @click.option(
             "--suffix",
             metavar="SUFFIX",
@@ -283,16 +296,14 @@ def gethashcli(name, suffix):
             is_flag=True,
             help="Do not output to files. This is the default output mode.",
         )
-        @click.option(
-            "--tqdm-ascii", type=click.BOOL, default=_TQDM_ASCII, show_default=True
-        )
+        @click.option("--tqdm-ascii", type=click.BOOL, default=False, show_default=True)
         @click.option(
             "--tqdm-disable", type=click.BOOL, default=False, show_default=True
         )
         @click.option("--tqdm-leave", type=click.BOOL, default=False, show_default=True)
         @click.option("--no-stdout", is_flag=True, help="Do not output to stdout.")
         @click.option("--no-stderr", is_flag=True, help="Do not output to stderr.")
-        @click.version_option(__version__)
+        @click.version_option(__version__, prog_name=cmdname)
         @functools.wraps(func)
         def wrapper(*args, **kwargs):
             return func(*args, **kwargs)
